#ifndef __USER_INTERFACE_H
#define __USER_INTERFACE_H

/**********************************************
*               Definitions
**********************************************/
#define K_3060_DLL_VERSION       104

#define K_3060_MAX_DEVICE        12
#define K_NODE_1       1
#define K_NODE_2       2

#define K_USED_BAR_MEM    6         // PCI_NUM_BARS_TYPE_00 in Plx.h

#define Packet_Size   256
#define Size_of_U32   4

// Aufteilung 12 Byte Header
#define K_HEADER_POS_START_BYTE         0
#define K_HEADER_POS_FLAGS              1
#define K_HEADER_POS_LENGTH_LOW         2
#define K_HEADER_POS_LENGTH_HIGH        3
#define K_HEADER_POS_TARGET_ADDRESS     4  // bei PXI Portnummer
#define K_HEADER_POS_TARGET_PORT        5
#define K_HEADER_POS_SOURCE_ADDRESS     6
#define K_HEADER_POS_SOURCE_PORT        7
#define K_HEADER_POS_TYPE               8
#define K_HEADER_POS_APPLICATIONHANDLE  9
#define K_HEADER_POS_DEVICE            10  // bei PXI Kartennummer
#define K_HEADER_POS_COMMAND           11

#define K_NUMBER_COUNT_HEADER          12

// ---------- XILINX Write ---------------------------------------------------------
// XILINX command structure
#define K_HEADER_XILINX_INSTRUCTION_GLOBAL      0    // start byte
#define K_HEADER_XILINX_CARD_NUMBER             1    // device (1 ... K_DEV_MAX)
#define K_HEADER_XILINX_PORT_NUMBER             2    // not used
#define K_HEADER_XILINX_INSTRUCTION             3    // command
#define K_HEADER_XILINX_FIRST_DATA              4    
#define K_HEADER_XILINX_LENGTH                  4     

#define K_READ                      0
#define K_WRITE                     1

#define K_HEADER_XILINX_START_BYTE  0x48

// XILINX commands
#define K_XILINX_CMD_PO_RESET       0x10
#define K_XILINX_CMD_EXT_CLOCK      0x11
#define K_XILINX_CMD_REG_WRITE      0x12

/**********************************************
*               Structures
**********************************************/
/*
typedef signed char      S8;
typedef unsigned char    U8;
typedef signed short     S16;
typedef unsigned short   U16;
typedef signed long      S32;
typedef unsigned long    U32;
*/



typedef struct
	{
	U32		SW_Version_XILINX;
	U32		HW_Version_XILINX;
	U32		HW_Name_XILINX;
	U32		Interface_XILINX;
	U32		GeoAddress;
	U32		SerialNumber;
	} t_Card_Info;

typedef struct
	{
	U32				DllVersion;
	U32				DriverVersion;
	U32				CardCount;
	t_Card_Info		CardInfo[K_3060_MAX_DEVICE];
	} t_Driver_Info;

typedef struct
	{
	U32	PciBarBaseAddress[K_USED_BAR_MEM];
	U32	PciBarRange[K_USED_BAR_MEM];
	U32	MemoryType[K_USED_BAR_MEM];                     // 0 -> IO ; 1 -> Memory
	} t_MemProperties;

typedef struct
	{
	U32		Mode;
	U32		Register;
	U32		Value;
	} t_RegReadWrite;

typedef struct _tCmdPackHeader
	{
	U32		mSubCode;                       // LSBUS_CMD_PACKAGE
	S32		mSerial;                        // -1: erstbester
	U32		mCountCmds;                     // total number of commands
	U32		mSizeCmds;                      // total number of bytes following command data
	}TCmdPackHeader, *PCmdPackHeader;

typedef struct
 { 
 U8 Device;                 // Device Nummer im Handle Array 
 U8 Space;                  // Space 0/1 fr Mikrocontroller 1/2
 U32 TargetAddr;            // Anfangsaddresse des ZielPuffers
 U32 TargetBufferLength;    // Gre des ZielPuffers    
 } DMA_setup, *pDMA_setup;



/******************************************
 * Goepel function
 *****************************************/
#ifdef __EXPORT_DLL	// creating DLL
	#define INTEGRATION_MODE	__declspec(dllexport)
#else				// using in customer application
	#define INTEGRATION_MODE	__declspec(dllimport)
#endif

#ifdef __cplusplus
	extern "C" {
#endif



INTEGRATION_MODE		S32
						Pxi3060__DriverInfo(
												t_Driver_Info	*pDriverInfo,
												U32				LengthInByte);
INTEGRATION_MODE		S32
						Pxi3060__XilinxReadWriteRegister(
												U8				*pData, 
												U32				*DataLength);
INTEGRATION_MODE		S32
						Pxi3060__WriteInstruction(
												U8				*pData, 
												U16				DataLength);
INTEGRATION_MODE		S32
						Pxi3060__ReadResponse(
												U8				Device,
												U8				Node,
												U8				*pData, 
												U32				*DataLength);
INTEGRATION_MODE		S32
						Pxi3060__ReadMonitor(
												U8				Device,
												U8				Node,
												U8				*pData, 
												U32				*DataLength);
INTEGRATION_MODE		S32
						Pxi3060__FPGA_Reconfiguration(
												U8				Device,
												S8				*pFileData);

#ifdef __cplusplus
	}
#endif


#endif
